@@ -43,7 +43,8 @@ namespace Lum {
     void CalcSize();
 
     void PrepareForBackground(OS::DrawInfo* draw);
-    void Draw(int x, int y, size_t w, size_t h);
+    void Draw(OS::DrawInfo* draw,
+              int x, int y, size_t w, size_t h);
 
     void Resync(Base::Model* model, const Base::ResyncMsg& msg);
   };
