@@ -22,7 +22,8 @@
 
 #include <Lum/Def/Menu.h>
 
-#include <Lum/OS/Behaviour.h>
+#include <Lum/Manager/Behaviour.h>
+
 #include <Lum/OS/Theme.h>
 
 #include <Lum/Window.h>
@@ -41,7 +42,7 @@ namespace Lum {
   private:
     Def::Menu                        *menuDef;
     Menu                             *menuPopup;
-    OS::Behaviour::CustomMenuHandler *customMenuHandler;
+    Manager::Behaviour::CustomMenuHandler *customMenuHandler;
     Lum::Object                      *toolbar;
     Lum::Object                      *main;
     Lum::Object                      *statusLine;
