@@ -21,7 +21,7 @@
 */
 
 #include <Lum/Model/Color.h>
-#include <Lum/Model/Integer.h>
+#include <Lum/Model/Number.h>
 
 #include <Lum/Object.h>
 
