@@ -34,7 +34,8 @@ namespace Lum {
     Object *label;
 
   protected:
-    void DrawContent(int x, int y, size_t w, size_t h);
+    void DrawContent(OS::DrawInfo* draw,
+                     int x, int y, size_t w, size_t h);
 
   public:
     Toggle();
