@@ -34,28 +34,33 @@ namespace Lum {
     selection(new Model::SingleLineSelection()),
     value(value)
   {
+    if (editable) {
+      assert(value!=NULL);
+    }
+    else {
+      assert(value==NULL);
+    }
+
     if (editable) {
       SetBackground(OS::display->GetFill(OS::Display::editComboBackgroundFillIndex));
+      value->SetParent(this);
     }
     else {
       SetBackground(OS::display->GetFill(OS::Display::comboBackgroundFillIndex));
+
+      if (!OS::display->GetTheme()->FocusOnEditableControlsOnly()) {
+        SetCanFocus(true);
+        RequestFocus();
+      }
     }
 
-    if (!OS::display->GetTheme()->FocusOnEditableControlsOnly()) {
-      SetCanFocus(true);
-      RequestFocus();
-    }
     SetRedrawOnMouseActive(true);
 
-    value->SetParent(this);
-
-    if (dynamic_cast<Control*>(value)==NULL) {
-      value->SetBackground(NULL);
-    }
-
     headerModel=new Model::HeaderImpl();
     headerModel->AddColumn(L"",Lum::Base::Size::pixel,0);
 
+    Observe(selection);
+
     Observe(prevAction);
     Observe(nextAction);
   }
@@ -70,6 +75,11 @@ namespace Lum {
     return value!=NULL && value->HasBaseline();
   }
 
+  Object* Combo::GetValueObject() const
+  {
+    return value;
+  }
+
   size_t Combo::GetBaseline() const
   {
     assert(value!=NULL);
@@ -83,25 +93,22 @@ namespace Lum {
     }
   }
 
-  Object* Combo::GetFocusObject()
-  {
-    if (value->CanFocus()) {
-      return value;
-    }
-    else {
-      return this;
-    }
-  }
-
   bool Combo::VisitChildren(Visitor &visitor, bool /*onlyVisible*/)
   {
-    if (!visitor.Visit(value)) {
+    if (value!=NULL &&
+        !visitor.Visit(value)) {
       return false;
     }
 
     return true;
   }
 
+  void Combo::PreparePainter(ValuePainter* painter)
+  {
+    painter->SetParent(this);
+    painter->SetModel(tableModel);
+  }
+
   /**
     Call this method to assign the table model that will be used to display
     all possible values in the pop window.
@@ -124,30 +131,29 @@ namespace Lum {
     tableModel=model;
 
     if (tableModel.Valid()) {
+      if (!tablePainter.Valid()) {
+        tablePainter=TableCellPainter::GetDefaultTableCellPainter(model);
+      }
+
       Observe(tableModel);
     }
   }
 
+  void Combo::SetTableCellPainter(TableCellPainter *tablePainter)
+  {
+    this->tablePainter=tablePainter;
+  }
+
   void Combo::CalcSize()
   {
-    /* Delegate Focus visualisation to value class, if possible */
-    if (value->RequestedFocus()) {
-      UnrequestFocus();
-    }
-
-    /*
-    if (editable) {
-      if (background.Valid() && background->HasBorder()) {
-        value->SetFrame(new OS::EmptyFrame());
-      }
-    }*/
-
-    value->SetFlex(true,true);
-    value->CalcSize();
+    assert(tablePainter.Valid());
 
     if (editable) {
       OS::ImageRef image=OS::display->GetImage(OS::Display::comboEditButtonImageIndex);
 
+      value->SetFlex(true,true);
+      value->CalcSize();
+
       minWidth=image->GetWidth()+value->GetOMinWidth();
       width=image->GetWidth()+value->GetOWidth();
 
@@ -167,11 +173,12 @@ namespace Lum {
 
       width=minWidth;
 
-      minWidth+=value->GetOMinWidth();
-      width+=value->GetOWidth();
+      PreparePainter(tablePainter);
+      minWidth+=tablePainter->GetProposedWidth();
+      width+=tablePainter->GetProposedWidth();
 
-      minHeight=std::max(value->GetOMinHeight(),image->GetHeight());
-      height=std::max(value->GetOHeight(),image->GetHeight());
+      minHeight=std::max(tablePainter->GetProposedHeight(),image->GetHeight());
+      height=std::max(tablePainter->GetProposedHeight(),image->GetHeight());
     }
 
     Control::CalcSize();
@@ -209,10 +216,11 @@ namespace Lum {
 
     combo->table->SetHeaderModel(combo->headerModel);
     combo->table->SetModel(combo->tableModel);
+    combo->table->SetPainter(combo->tablePainter);
     combo->table->SetSelection(combo->selection);
-    combo->table->GetTableView()->SetAutoFitColumns(true);
-    combo->table->GetTableView()->SetAutoHSize(true);
-    combo->table->GetTableView()->SetAutoVSize(true);
+    combo->table->SetAutoFitColumns(true);
+    combo->table->SetAutoHSize(true);
+    combo->table->SetAutoVSize(true);
 
     RegisterCommitShortcut(combo->table->GetTableView(),
                            combo->table->GetTableView()->GetMouseSelectionAction());
@@ -255,9 +263,10 @@ namespace Lum {
       popup->Close();
 
       if (popup->success &&
+          HasModel() &&
           tableModel.Valid() &&
           selection->HasSelection()) {
-        CopySelection(selection->GetLine());
+        SetModelFromSelection();
       }
     }
 
@@ -267,17 +276,30 @@ namespace Lum {
 
   void Combo::SetTableRow(size_t row)
   {
-    selection->SelectCell(1,row);
-    CopySelection(row);
+    if (tableModel.Valid() && tableModel->GetRows()>0) {
+      if (row>0) {
+        selection->SelectCell(1,row);
+      }
+      else {
+        selection->Clear();
+      }
+    }
+
+
+    if (HasModel() && tableModel.Valid()) {
+      SetModelFromSelection();
+    }
   }
 
   bool Combo::HandleMouseEvent(const OS::MouseEvent& event)
   {
-    if (!visible || (GetModel()==NULL) || !GetModel()->IsEnabled()) {
+    if (!visible || !HasModel() || !GetModel()->IsEnabled()) {
       return false;
     }
 
-    if (event.type==OS::MouseEvent::down && PointIsIn(event) && event.button==OS::MouseEvent::button1) {
+    if (event.type==OS::MouseEvent::down &&
+        PointIsIn(event) &&
+        event.button==OS::MouseEvent::button1) {
       OpenPopup();
       return true;
     }
@@ -287,7 +309,9 @@ namespace Lum {
 
   bool Combo::HandleKeyEvent(const OS::KeyEvent& event)
   {
-    if (dynamic_cast<Control*>(value)!=NULL && dynamic_cast<Control*>(value)->HandleKeyEvent(event)) {
+    if (value!=NULL &&
+        dynamic_cast<Control*>(value)!=NULL &&
+        dynamic_cast<Control*>(value)->HandleKeyEvent(event)) {
       return true;
     }
 
@@ -326,27 +350,6 @@ namespace Lum {
                     y+(height-value->GetOHeight()) / 2);
       }
     }
-    else {
-      OS::ImageRef image=OS::display->GetImage(OS::Display::comboImageIndex);
-      OS::ImageRef divider=OS::display->GetImage(OS::Display::comboDividerImageIndex);
-
-      value->Resize(width-
-                    image->GetWidth()-
-                    2*OS::display->GetSpaceHorizontal(OS::Display::spaceIntraObject)-
-                    divider->GetWidth(),
-                    height-2*OS::display->GetSpaceVertical(OS::Display::spaceObjectBorder));
-
-      if (imageRight) {
-        value->Move(x,
-                    y+(height-value->GetOHeight()) / 2);
-      }
-      else {
-        value->Move(x+image->GetWidth()+
-                    2*OS::display->GetSpaceHorizontal(OS::Display::spaceIntraObject)+
-                     divider->GetWidth(),
-                    y+(height-value->GetOHeight()) / 2);
-      }
-    }
 
     Control::Layout();
   }
@@ -359,9 +362,10 @@ namespace Lum {
     draw->disabled=!(GetModel()!=NULL) || GetModel()->IsNull() || !GetModel()->IsEnabled();
   }
 
-  void Combo::Draw(int x, int y, size_t w, size_t h)
+  void Combo::Draw(OS::DrawInfo* draw,
+                   int x, int y, size_t w, size_t h)
   {
-    Control::Draw(x,y,w,h);
+    Control::Draw(draw,x,y,w,h);
 
     if (!OIntersect(x,y,w,h)) {
       return;
@@ -369,8 +373,6 @@ namespace Lum {
 
     /* --- */
 
-    OS::DrawInfo *draw=GetDrawInfo();
-
     draw->selected=false;
     draw->activated=IsMouseActive();
     draw->focused=HasFocus();
@@ -393,6 +395,13 @@ namespace Lum {
       OS::ImageRef image=OS::display->GetImage(OS::Display::comboImageIndex);
       OS::ImageRef divider=OS::display->GetImage(OS::Display::comboDividerImageIndex);
 
+      size_t valueWidth=width-
+                        image->GetWidth()-
+                        2*OS::display->GetSpaceHorizontal(OS::Display::spaceIntraObject)-
+                        divider->GetWidth();
+      size_t valueHeight=height;
+
+
       if (imageRight) {
         divider->DrawStretched(draw,
                                this->x+width-
@@ -407,19 +416,39 @@ namespace Lum {
                     this->x+width-
                     image->GetWidth(),
                     this->y+(height-image->GetHeight()) / 2);
+
+        if (selection->HasSelection()) {
+          PreparePainter(tablePainter);
+          tablePainter->SetCell(1,selection->GetLine());
+          tablePainter->Draw(draw,
+                             this->x,
+                             this->y+(height-valueHeight) / 2,
+                             valueWidth,
+                             valueHeight);
+        }
+
       }
       else {
         image->Draw(draw,
-                    x,
+                    this->x,
                     this->y+(height-image->GetHeight()) / 2);
 
         divider->DrawStretched(draw,
-                               x+image->GetWidth()+
+                               this->x+image->GetWidth()+
                                OS::display->GetSpaceHorizontal(OS::Display::spaceIntraObject),
                                this->y,
                                image->GetWidth(),
                                height);
 
+        if (selection->HasSelection()) {
+          PreparePainter(tablePainter);
+          tablePainter->SetCell(1,selection->GetLine());
+          tablePainter->Draw(draw,
+                             this->x+width-valueWidth,
+                             this->y+(height-valueHeight) / 2,
+                             valueWidth,
+                             valueHeight);
+        }
       }
     }
 
@@ -428,24 +457,6 @@ namespace Lum {
     draw->disabled=false;
   }
 
-  void Combo::DrawFocus()
-  {
-    if (editable && value!=NULL) {
-      value->SetShowFocus(true);
-    }
-
-    Control::DrawFocus();
-  }
-
-  void Combo::HideFocus()
-  {
-    if (editable && value!=NULL) {
-      value->SetShowFocus(false);
-    }
-
-    Control::HideFocus();
-  }
-
   void Combo::Hide()
   {
     if (visible) {
@@ -480,7 +491,12 @@ namespace Lum {
           SetTableRow(1);
         }
       }
-      else if (model==tableModel && visible) {
+      else if (model==tableModel) {
+        SetSelectionFromModel();
+        Redraw();
+      }
+      else if (model==GetModel()) {
+        SetSelectionFromModel();
         Redraw();
       }
     }
@@ -489,7 +505,7 @@ namespace Lum {
   }
 
   TextCombo::TextCombo()
-  : Combo(new Text(),false),
+  : Combo(NULL,false),
     model(NULL)
   {
     // no code
@@ -513,7 +529,7 @@ namespace Lum {
     This method will be called if a new value was selected from the popup
     window. The baseclass will try its best to assign a sensefull value to
     the model assigned to Combo. If the model is numemric it will
-    assign the index of the current selcted (starting with 0), if its of type
+    assign the index of the current selceted (starting with 0), if its of type
     text, if will assign the text of the current selected (if the table model
     has more than one coloum if will iterate from left to right until some
     valid text will be returned).
@@ -521,46 +537,73 @@ namespace Lum {
     If you want some other (or more) behaviour, overwrite this method
     and call baseclass if necessary.
   */
-  void TextCombo::CopySelection(size_t row)
+  void TextCombo::SetModelFromSelection()
   {
-    if (tableModel.Valid()) {
-      size_t       x=1;
-      std::wstring res;
+    if (selection->HasSelection()) {
+      if (dynamic_cast<const StringCellPainter*>(tablePainter.Get())!=NULL) {
+        StringCellPainter* p=dynamic_cast<StringCellPainter*>(tablePainter.Get());
 
-      while (res.empty() && x<=headerModel->GetColumns()) {
-        res=tableModel->GetString(x,row);
-        x++;
-      }
+        PreparePainter(p);
 
-      dynamic_cast<Text*>(value)->SetText(res);
-
-      if (model.Valid()) {
-        model->Set(res);
+        p->SetCell(1,selection->GetLine());
+        model->Set(p->GetCellData());
       }
     }
-
-    if (tableModel.Valid() && tableModel->GetRows()>0) {
-      if (row>0) {
-        selection->SelectCell(1,row);
-      }
-      else {
-        selection->Clear();
-      }
+    else {
+      model->SetNull();
     }
   }
 
-  void TextCombo::Resync(Base::Model* model, const Base::ResyncMsg& msg)
+  void TextCombo::SetSelectionFromModel()
   {
-    if (model==this->model) {
-      dynamic_cast<Text*>(value)->SetText(this->model->Get());
+    if (!selection.Valid()) {
+      return;
     }
 
-    Combo::Resync(model,msg);
-  }
+    if (!model.Valid()) {
+      selection->Clear();
+      return;
+    }
 
+    if (!tableModel.Valid()) {
+      selection->Clear();
+      return;
+    }
+
+    if (dynamic_cast<StringCellPainter*>(tablePainter.Get())==NULL) {
+      selection->Clear();
+      return;
+    }
+
+    StringCellPainter *p=dynamic_cast<StringCellPainter*>(tablePainter.Get());
+    Model::String     *m=dynamic_cast<Model::String*>(model.Get());
+
+    if (m==NULL) {
+      selection->Clear();
+      return;
+    }
+
+    if (m->IsNull()) {
+      selection->Clear();
+    }
+    else {
+      PreparePainter(p);
+
+      for (size_t r=1; r<=tableModel->GetRows(); r++) {
+        p->SetCell(1,r);
+
+        if (m->Get()==p->GetCellData()) {
+          selection->SelectLine(r);
+          return;
+        }
+      }
+
+      selection->Clear();
+    }
+  }
 
   IndexCombo::IndexCombo()
-  : Combo(new Text(),false),
+  : Combo(NULL,false),
     model(NULL)
   {
     // no code
@@ -580,64 +623,45 @@ namespace Lum {
     return this->model.Valid();
   }
 
-  void IndexCombo::CopySelection(size_t row)
+  void IndexCombo::SetModelFromSelection()
   {
-    if (tableModel.Valid()) {
-      size_t       x=1;
-      std::wstring res;
-
-      while (res.empty() && x<=headerModel->GetColumns()) {
-        res=tableModel->GetString(x,row);
-        x++;
-      }
-
-      dynamic_cast<Text*>(value)->SetText(res);
-
-      if (model.Valid()) {
-        model->Set(row);
-      }
+    if (selection->HasSelection()) {
+      model->Set(selection->GetLine());
     }
-
-    if (tableModel.Valid() && tableModel->GetRows()>0) {
-      if (row>0) {
-        selection->SelectCell(1,row);
-      }
-      else {
-        selection->Clear();
-      }
+    else {
+      this->model->SetNull();
     }
   }
 
-  void IndexCombo::Resync(Base::Model* model, const Base::ResyncMsg& msg)
+  void IndexCombo::SetSelectionFromModel()
   {
-    if ((model==tableModel || model==this->model) &&
-        this->model.Valid() && tableModel.Valid()) {
-      size_t       x=1;
-      std::wstring res;
-
-      if (!this->model->IsNull()) {
-        if (this->model->Get()<=tableModel->GetRows()) {
-          selection->SelectCell(1,this->model->Get());
-
-          while (res.empty() && x<=headerModel->GetColumns()) {
-            res=tableModel->GetString(x,this->model->Get());
-            x++;
-          }
-
-          dynamic_cast<Text*>(value)->SetText(res);
-        }
-        else {
-          this->model->SetNull();
-          dynamic_cast<Text*>(value)->SetText(L"");
-        }
-      }
-
-    }
-    else if (model==this->model) {
-      Redraw();
+    if (!selection.Valid()) {
+      return;
     }
 
-    Combo::Resync(model,msg);
+    if (!model.Valid()) {
+      selection->Clear();
+      return;
+    }
+
+    if (!tableModel.Valid()) {
+      selection->Clear();
+      return;
+    }
+
+    Model::SizeT *m=dynamic_cast<Model::SizeT*>(model.Get());
+
+    if (m==NULL) {
+      selection->Clear();
+      return;
+    }
+
+    if (m->IsNull() || m->Get()==0 || m->Get()>tableModel->GetRows()) {
+      selection->Clear();
+    }
+    else {
+      selection->SelectLine(m->Get());
+    }
   }
 
   IndexCombo* IndexCombo::Create(Lum::Model::SizeT* index,
@@ -654,7 +678,7 @@ namespace Lum {
   }
 
   TextEditCombo::TextEditCombo()
-  : Combo(new String,true),
+  : Combo(new String(),true),
     model(NULL)
   {
     string=dynamic_cast<String*>(value);
@@ -687,30 +711,68 @@ namespace Lum {
     return string;
   }
 
-  void TextEditCombo::CopySelection(size_t row)
+  void TextEditCombo::SetModelFromSelection()
   {
-    if (tableModel.Valid()) {
-      size_t       x;
-      std::wstring res;
+    if (selection->HasSelection()) {
+      if (dynamic_cast<const StringCellPainter*>(tablePainter.Get())!=NULL) {
+        StringCellPainter* p=dynamic_cast<StringCellPainter*>(tablePainter.Get());
 
-      x=1;
-      while (res.empty() && x<=headerModel->GetColumns()) {
-        res=tableModel->GetString(x,row);
-        x++;
-      }
+        PreparePainter(p);
 
-      if (model.Valid()) {
-        model->Set(res);
+        p->SetCell(1,selection->GetLine());
+        model->Set(p->GetCellData());
       }
     }
+    else {
+      model->SetNull();
+    }
+  }
 
-    if (tableModel.Valid() && tableModel->GetRows()>0) {
-      if (row>0) {
-        selection->SelectCell(1,row);
-      }
-      else {
-        selection->Clear();
+  void TextEditCombo::SetSelectionFromModel()
+  {
+    if (!selection.Valid()) {
+      return;
+    }
+
+    if (!model.Valid()) {
+      selection->Clear();
+      return;
+    }
+
+    if (!tableModel.Valid()) {
+      selection->Clear();
+      return;
+    }
+
+    if (dynamic_cast<StringCellPainter*>(tablePainter.Get())==NULL) {
+      selection->Clear();
+      return;
+    }
+
+    StringCellPainter *p=dynamic_cast<StringCellPainter*>(tablePainter.Get());
+    Model::String     *m=dynamic_cast<Model::String*>(model.Get());
+
+    if (m==NULL) {
+      selection->Clear();
+      return;
+    }
+
+    if (m->IsNull()) {
+      selection->Clear();
+    }
+    else {
+      PreparePainter(p);
+
+      for (size_t r=1; r<=tableModel->GetRows(); r++) {
+        p->SetCell(1,r);
+
+        if (m->Get()==p->GetCellData()) {
+          selection->SelectLine(r);
+          return;
+        }
       }
+
+      selection->Clear();
     }
   }
 }
