@@ -70,9 +70,10 @@ namespace Lum {
     Control::Layout();
   }
 
-  void FuelGauge::Draw(int x, int y, size_t w, size_t h)
+  void FuelGauge::Draw(OS::DrawInfo* draw,
+                       int x, int y, size_t w, size_t h)
   {
-    Control::Draw(x,y,w,h);
+    Control::Draw(draw,x,y,w,h);
 
     if (!OIntersect(x,y,w,h)) {
       return;
@@ -80,8 +81,6 @@ namespace Lum {
 
     /* --- */
 
-    OS::DrawInfo *draw=GetDrawInfo();
-
     if (!model.Valid() || model->IsNull()) {
       return;
     }
