@@ -21,7 +21,7 @@
 
 #include <Lum/OS/Driver.h>
 #include <Lum/OS/Theme.h>
-#include <Lum/OS/Manager/Repository.h>
+#include <Lum/Manager/Display.h>
 
 #include <iostream>
 
@@ -42,7 +42,7 @@ namespace Lum {
         focusOutAction(new Model::Action),
         mouseInAction(new Model::Action),
         mouseOutAction(new Model::Action),
-        redrawAction(new Model::Action),
+        drawAction(new Model::Action),
         resizeAction(new Model::Action),
         preInitAction(new Model::Action),
         eventAction(new Model::Action),
@@ -167,9 +167,9 @@ namespace Lum {
         return resizeAction.Get();
       }
 
-      Model::Action* Window::GetRedrawAction() const
+      Model::Action* Window::GetDrawAction() const
       {
-        return redrawAction.Get();
+        return drawAction.Get();
       }
 
       Model::Action* Window::GetPreInitAction() const
@@ -337,14 +337,74 @@ namespace Lum {
         return parent;
       }
 
-      OS::DrawInfo* Window::GetDrawInfo() const
+      DrawInfo* Window::RequestDrawInfo(int x, int y, size_t width, size_t height)
       {
-        if (backgroundDraw!=NULL) {
-          return backgroundDraw;
-        }
-        else {
+        assert(backgroundBitmap==NULL);
+
+        backgroundBitmap=driver->CreateBitmap(GetWidth(),GetHeight());
+
+        if (backgroundBitmap==NULL) {
           return draw;
         }
+
+        backgroundDraw=backgroundBitmap->GetDrawInfo();
+
+        if (backgroundDraw==NULL) {
+          delete backgroundBitmap;
+          backgroundBitmap=NULL;
+
+          return draw;
+        }
+
+        draw->CopyToBitmap(x,y,width,height,x,y,backgroundBitmap);
+
+        return backgroundDraw;
+      }
+
+      void Window::ReleaseDrawInfo(int x, int y, size_t width, size_t height)
+      {
+        if (backgroundBitmap!=NULL) {
+          draw->CopyFromBitmap(backgroundBitmap,x,y,width,height,x,y);
+
+          delete backgroundBitmap;
+          backgroundBitmap=NULL;
+          backgroundDraw=NULL;
+        }
+      }
+
+      DrawInfo* Window::RequestRefreshDrawInfo(int x, int y, size_t width, size_t height)
+      {
+        assert(backgroundBitmap==NULL);
+
+        backgroundBitmap=driver->CreateBitmap(GetWidth(),GetHeight());
+
+        if (backgroundBitmap==NULL) {
+          return draw;
+        }
+
+        backgroundDraw=backgroundBitmap->GetDrawInfo();
+
+        if (backgroundDraw==NULL) {
+          delete backgroundBitmap;
+          backgroundBitmap=NULL;
+
+          return draw;
+        }
+
+        draw->CopyToBitmap(x,y,width,height,x,y,backgroundBitmap);
+
+        return backgroundDraw;
+      }
+
+      void Window::ReleaseRefreshDrawInfo(int x, int y, size_t width, size_t height)
+      {
+        if (backgroundBitmap!=NULL) {
+          draw->CopyFromBitmap(backgroundBitmap,x,y,width,height,x,y);
+
+          delete backgroundBitmap;
+          backgroundBitmap=NULL;
+          backgroundDraw=NULL;
+        }
       }
 
       OS::Window::Type Window::GetType() const
@@ -664,39 +724,6 @@ namespace Lum {
         }
       }
 
-      bool Window::SwitchBackgroundDrawInfo(int x, int y, size_t width, size_t height)
-      {
-        if (backgroundBitmap==NULL) {
-          backgroundBitmap=driver->CreateBitmap(GetWidth(),GetHeight());
-
-          if (backgroundBitmap==NULL) {
-            return false;
-          }
-
-          backgroundDraw=backgroundBitmap->GetDrawInfo();
-
-          if (backgroundDraw==NULL) {
-            delete backgroundBitmap;
-            backgroundBitmap=NULL;
-
-            return false;
-          }
-
-          draw->CopyToBitmap(x,y,width,height,x,y,backgroundBitmap);
-
-          return true;
-        }
-        else {
-          draw->CopyFromBitmap(backgroundBitmap,x,y,width,height,x,y);
-
-          delete backgroundBitmap;
-          backgroundBitmap=NULL;
-          backgroundDraw=NULL;
-
-          return true;
-        }
-      }
-
       void Window::TriggerResize(size_t width, size_t height)
       {
         OS::Window::ResizeMsg msg;
@@ -707,43 +734,6 @@ namespace Lum {
         resizeAction->Trigger(msg);
       }
 
-      void Window::TriggerRedraw(int x, int y, size_t width, size_t height)
-      {
-        OS::Window::RedrawMsg msg;
-
-        // Somebody has likely called Object::Redraw() during a draw => We ignore this...
-        if (!redrawAction->IsInactive()) {
-          return;
-        }
-
-        // We do not redraw anything if the display is off...
-        if (Manager::repository->GetDisplayManager()!=NULL &&
-            Manager::repository->GetDisplayManager()->GetDisplayState()==OS::Manager::DisplayManager::DisplayStateOff) {
-          return;
-        }
-
-        msg.x=x;
-        msg.y=y;
-        msg.width=width;
-        msg.height=height;
-
-        if (IsShown() && !onOpened) {
-          TriggerPreOpened();
-        }
-
-        if (SwitchBackgroundDrawInfo(x,y,width,height)) {
-          redrawAction->Trigger(msg);
-          SwitchBackgroundDrawInfo(x,y,width,height);
-        }
-        else {
-          redrawAction->Trigger(msg);
-        }
-
-        if (IsShown() && !onOpened) {
-          TriggerOpened();
-        }
-      }
-
       void Window::TriggerGrabCancel()
       {
         grabCancelAction->Trigger();
