@@ -49,6 +49,23 @@ namespace Lum {
         pen=0;
       }
 
+      DrawInfo::DrawInfo(OS::Window* window, HDC dc)
+      : OS::Base::DrawInfo(window)
+      {
+        hwnd=dynamic_cast<Window*>(window)->window;
+        this->dc=dc;
+
+        /* ignore */ SetGraphicsMode(dc,GM_ADVANCED);
+        /* ignore */ SetROP2(dc,R2_COPYPEN);
+        /* ignore */ SetTextAlign(dc,TA_BASELINE+TA_LEFT);
+        /* ignore */ SetMapMode(dc,MM_TEXT);
+        /* ignore */ SetBkMode(dc,TRANSPARENT);
+        /* ignore */ SetBkColor(dc,RGB(0,0,0));
+
+        brush=0;
+        pen=0;
+      }
+      
       DrawInfo::DrawInfo(OS::Bitmap* window)
       : OS::Base::DrawInfo(window)
       {
