@@ -197,11 +197,12 @@ namespace Lum {
     draw->selected=false;
     draw->activated=false;
     draw->focused=false;
+    draw->disabled=false;
   }
 
   void State::Resync(Base::Model* model, const Base::ResyncMsg& msg)
   {
-    if (visible && (model==boolModel || model==sizeTModel)) {
+    if (model==boolModel || model==sizeTModel) {
       Redraw();
     }
 
