@@ -102,14 +102,13 @@ namespace Lum {
 
   void TextLabel::PrepareForBackground(OS::DrawInfo* draw)
   {
-    draw->focused=HasFocus() || DisplayFocus();
+    draw->focused=HasFocus() || ShowFocus();
   }
 
-  void TextLabel::Draw(int x, int y, size_t w, size_t h)
+  void TextLabel::Draw(OS::DrawInfo* draw,
+                       int x, int y, size_t w, size_t h)
   {
-    OS::DrawInfo *draw=GetDrawInfo();
-
-    Object::Draw(x,y,w,h);
+    Object::Draw(draw,x,y,w,h);
 
     if (!OIntersect(x,y,w,h)) {
       return;
